package com.thalesgroup.parameters;

import com.thalesgroup.parameters.BoolParameterValue;
import com.thalesgroup.parameters.DoubleParameterValue;
import com.thalesgroup.parameters.IntParameterValue;
import com.thalesgroup.parameters.ParameterSet;
import com.thalesgroup.parameters.ParametersFactory;
import com.thalesgroup.parameters.StringParameterValue;

public class ParametersUtils
{
  private ParametersUtils()
  {}

  /**
   * Create ParameterSet.
   * 
   * @param name
   * @return
   */
  public static ParameterSet createParameterSet(String name)
  {
    ParameterSet parameterSet = ParametersFactory.eINSTANCE.createParameterSet();
    parameterSet.setName(name);
    return parameterSet;
  }

  /**
   * Create Bool Parameter.
   * 
   * @param parameterSet
   * @param name
   * @param value
   * @return
   */
  public static BoolParameterValue createBooleanParameter(ParameterSet parameterSet, String name, boolean value)
  {
    BoolParameterValue boolParameter = ParametersFactory.eINSTANCE.createBoolParameterValue();

    // Set name and value
    boolParameter.setName(name);
    boolParameter.setValue(value);

    // Add to ParameterSet
    parameterSet.getOwnedParameters().add(boolParameter);

    return boolParameter;
  }

  /**
   * Create Int Parameter.
   * 
   * @param parameterSet
   * @param name
   * @param value
   * @return
   */
  public static IntParameterValue createIntegerParameter(ParameterSet parameterSet, String name, int value)
  {
    IntParameterValue intParameter = ParametersFactory.eINSTANCE.createIntParameterValue();

    // Set name and value
    intParameter.setName(name);
    intParameter.setValue(value);

    // Add to ParameterSet
    parameterSet.getOwnedParameters().add(intParameter);

    return intParameter;
  }

  /**
   * Create Double Parameter.
   * 
   * @param parameterSet
   * @param name
   * @param value
   * @return
   */
  public static DoubleParameterValue createDoubleParameter(ParameterSet parameterSet, String name, double value)
  {
    DoubleParameterValue doubleParameter = ParametersFactory.eINSTANCE.createDoubleParameterValue();

    // Set name and value
    doubleParameter.setName(name);
    doubleParameter.setValue(value);

    // Add to ParameterSet
    parameterSet.getOwnedParameters().add(doubleParameter);

    return doubleParameter;
  }

  /**
   * Create String Parameter.
   * 
   * @param parameterSet
   * @param name
   * @param value
   * @return
   */
  public static StringParameterValue createStringParameter(ParameterSet parameterSet, String name, String value)
  {
    StringParameterValue stringParameter = ParametersFactory.eINSTANCE.createStringParameterValue();

    // Set name and value
    stringParameter.setName(name);
    stringParameter.setValue(value);

    // Add to ParameterSet
    parameterSet.getOwnedParameters().add(stringParameter);

    return stringParameter;
  }
}
